api.authentication.v1.user package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.user package

## Submodules

## api.authentication.v1.user.user_apikey module

Autogenerated API

`api.authentication.v1.user.user_apikey.` `disable_method_for_user`(userID: int, method: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Disable an authentication method for a user (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user to modify method (str) – Authentication method to enable
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 629, “limit”: 102, “responseCode”: 200, “count”: 906, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Ago every beyond school church project end fear.”, “messageTemplate”: “Able look can continue control.”, “field”: “Marriage actually listen method now.”, “parameter”: {}, “timestamp”: 232574749}], “currentPage”: 379, “size”: 793}

`api.authentication.v1.user.user_apikey.` `enable_method_for_user`(userID: int, method: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Enable an authentication method for a user (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user to modify method (str) – Authentication method to enable
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 434, “limit”: 1, “responseCode”: 200, “count”: 913, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Billion firm high property middle instead serious someone.”, “messageTemplate”: “Discover various evening war it assume black.”, “field”: “Nor respond dog.”, “parameter”: {}, “timestamp”: 976807680}], “currentPage”: 633, “size”: 523}

`api.authentication.v1.user.user_apikey.` `get_user_methods`(userId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List authentication methods enabled for a specified user (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – User to fetch methods for
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 4, “limit”: 414, “responseCode”: 200, “count”: 220, “data”: [{“method”: “SIGNATURE”, “lastLoginTimestamp”: 856951436, “lastLoginIP”: “Card interesting group material role child.”, “initialized”: false, “settings”: {“additionalProperties”: {}}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “May let make.”, “messageTemplate”: “Question front adult town thank professional.”, “field”: “Mouth their watch however pay management suggest.”, “parameter”: {}, “timestamp”: 420537912}], “currentPage”: 926, “size”: 396}

`api.authentication.v1.user.user_apikey.` `initiate`(userID: int, description: str = None, validSources: <function list at 0x7fcd55eae840> = None, expirationDays: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user APIkey (PUBLIC) API keys are bound to a limited IP range. The API key initialization request must specify an IP address or subnet which the API key can be used from.Attempts to use an api key from an IP outside this IP, will result in authentication error.

  To allow authentication from different IPs, issue multiple API keys.

  The initiation request returns the API key, in the format it can be used both in the Argus-API-Key header, or when initiating a durable session (/apikey/authenticate).

  The API key cannot be retrieved at a later stage. If the key is lost, it should be deletedand a new key should be issued.

  Return type: | `dict`

`api.authentication.v1.user.user_apikey.` `list`(userID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List user API keys (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 400, “limit”: 566, “responseCode”: 200, “count”: 647, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Indeed include listen something why or.”, “messageTemplate”: “People operation spring organization have election kid plan.”, “field”: “Huge party leave employee doctor.”, “parameter”: {}, “timestamp”: 134388218}], “currentPage”: 688, “size”: 390}

`api.authentication.v1.user.user_apikey.` `renew`(userID: int, keyID: int, expirationDays: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Renew existing user APIkey (PUBLIC) API keys have limited validity. This operationallows the administrator to renew a users API-key, to allow it to remain functional for a new validity period.

  Return type: | `dict`

`api.authentication.v1.user.user_apikey.` `retrieve_s_m_s_token`(userID: int, tokenSuffix: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Retrieve the SMS code sent to user (PUBLIC) SMS authentication depends on the verification code sent to the user by SMS reachingthe user. When this does not happen, this method allows an administrator to retrieve the SMS code to provide the user by phone.

  To retrieve the token, the user must provide the administrator with thesession token printed in the browser in the SMS code input screen.

  Return type: | `dict`

`api.authentication.v1.user.user_apikey.` `revoke`(userID: int, keyID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete existing user APIkey (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user keyID (int) – Key ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 213, “limit”: 717, “responseCode”: 200, “count”: 97, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Character teacher compare behavior.”, “messageTemplate”: “Require the cost cover you second.”, “field”: “You enter trip they effort.”, “parameter”: {}, “timestamp”: 191544647}], “currentPage”: 500, “size”: 986}

## Module contents